; ***************************************************************
;
; grille.asm
;
;***********************************************************************
; Pinbelegung 16F1825
;
;                   +---###---+
;           Vdd +++ |  1   14 | --- Vss
; PIEZO  OSC / RA 5 |  2   13 | RA 0 / PGD / TX  PIEZO
;        OSC / RA 4 |  3   12 | RA 1 / PGC / RX
;  input VPP / RA 3 |  4   11 | RA 2
;      CCP 1 / RC 5 |  5   10 | RC 0 / SCL
;              RC 4 |  6    9 | RC 1 / SDA
;              RC 3 |  7    8 | RC 2
;                   +---------+
;
;***********************************************************************

	list p=16f1825
	#include <p16f1825.inc>

	ERRORLEVEL -302				; schaltet Bank-Warnungen ab

	__CONFIG    _CONFIG1, _CP_OFF & _BOREN_OFF & _MCLRE_OFF & _PWRTE_ON & _WDTE_OFF & _FOSC_INTOSC & _CLKOUTEN_OFF
	__CONFIG    _CONFIG2, _PLLEN_OFF & _BORV_19 & _LVP_OFF & _FCMEN_OFF

;***********************************************************************

; 0x070 bis 0x07f ist in allen Banks gleich

	cblock 0x70

	endc

; 0x020 bis 0x06f ist in jeder Bank anders

	cblock 0x20					; Bank 0

	c00							; Zhler fr Bursts
	c01							; Zhler fr Pause lang

	endc


bank0 macro
	movlb	0x00				; Bank 0
	endm

bank1 macro
	movlb	0x01				; Bank 1
	endm

bank2 macro
	movlb	0x02				; Bank 2
	endm

bank3 macro
	movlb	0x03				; Bank 3
	endm

bank4 macro
	movlb	0x04				; Bank 4
	endm

bank5 macro
	movlb	0x05				; Bank 5
	endm

bank6 macro
	movlb	0x06				; Bank 6
	endm

bank7 macro
	movlb	0x07				; Bank 7
	endm

;***********************************************************************
;***********************************************************************

	org		0x00

	goto	init

;***********************************************************************

init

; Ports

	bank3
	clrf	ANSELA				; Port A digital
	clrf	ANSELC				; Port C digital

	bank1
	clrf	TRISA				; Port A alle output (A3 immer Input)
	clrf	TRISC				; Port C alle output

	bank0
	clrf	PORTA				; Ports initialisieren
	clrf	PORTC


; internen Oscillator einstellen, falls konfiguriert
; x0000xxx    31 kHz
; x0101xxx   125 kHz

	bank1
	movlw	B'00101000'			; 125 kHz
	movwf	OSCCON

; xx011111   maxim. Frequenz
; xx011110
;
; xx000001
; xx000000   kalib. Frequenz
; xx111111
;
; xx100001
; xx100000   minim. Frequenz

	movlw	B'00000000'			; hier Frequenz etwas nderbar
	movwf	OSCTUNE

; Interrupts

	bank0
	clrf	INTCON  			; Interrupt disable

; Timer 0 einstellen

	bank1
	bcf		OPTION_REG, T0CS	; Takt intern
	bcf		OPTION_REG, PSA		; Takt ber Prescaler
	bcf		OPTION_REG, PS2		; 000 = prescaler=1/2
	bcf		OPTION_REG, PS1		; 100 = prescaler=1/32
	bsf		OPTION_REG, PS0		; 111 = prescaler=1/256

; verschiedenes

	bank0

;***********************************************************************
;***********************************************************************

main

	movlw	0x08				; Vorbesetzung Zhler fr Bursts
	movwf	c00

	movlw	0x10				; Vorbesetzung Zhler fr Pause lang
	movwf	c01

; PIEZO an PORTA0 (Pin 13) und PORTA5 (Pin 2)
; p0 = eine Schwingung 

p0
	movlw	B'00100000'			; Ausgnge setzen: 5
	movwf	PORTC
	movlw	B'00110000'			; Ausgnge setzen: 5 4
	movwf	PORTC
	nop
	movlw	B'00000001'			; Ausgnge setzen: 0
	movwf	PORTC
	movlw	B'00000011'			; Ausgnge setzen: 0 1
	movwf	PORTC

; ca 32 msec Ton

	btfss	INTCON, TMR0IF		; Timer 0 bergelaufen ?
	goto	p0
	bcf		INTCON, TMR0IF		; Timer 0 flag bit rcksetzen

; ca 32 msec Pause kurz

p1
	btfss	INTCON, TMR0IF		; Timer 0 bergelaufen ?
	goto	p1
	bcf		INTCON, TMR0IF		; Timer 0 flag bit rcksetzen

; 8 Bursts

p2
	decfsz	c00, f				; zhlt von 8 auf 0
	goto	p0

; Pause lang

p3
	btfss	INTCON, TMR0IF		; Timer 0 bergelaufen ?
	goto	p3
	bcf		INTCON, TMR0IF		; Timer 0 flag bit rcksetzen

	decfsz	c01, f				; zhlt von 16 auf 0
	goto	p3

	goto	main


;***********************************************************************

	end
